@@ -31,5 +31,8 @@
 from easybuild.framework.easyconfig.default import ALL_CATEGORIES
 globals().update(ALL_CATEGORIES)
 
+# subdirectory (of 'easybuild' dir) in which easyconfig files are located in a package
+EASYCONFIGS_PKG_SUBDIR = 'easyconfigs'
+
 # is used in some tools
 from easybuild.framework.easyconfig.easyconfig import EasyConfig
