@@ -23,20 +23,19 @@
 # along with EasyBuild.  If not, see <http://www.gnu.org/licenses/>.
 ##
 """
-EasyBuild support for impmkl compiler toolchain (includes Intel compilers (icc, ifort), MPICH2,
+EasyBuild support for impmkl compiler toolchain (includes Intel compilers (icc, ifort), MPICH,
 Intel Math Kernel Library (MKL) , and Intel FFTW wrappers.
 
 @author: Kenneth Hoste (Ghent University)
 """
 
-from easybuild.toolchains.compiler.inteliccifort import IntelIccIfort
+from easybuild.toolchains.impich import Impich
 from easybuild.toolchains.fft.intelfftw import IntelFFTW
-from easybuild.toolchains.mpi.mpich2 import Mpich2
 from easybuild.toolchains.linalg.intelmkl import IntelMKL
 
-class Impmkl(IntelIccIfort, Mpich2, IntelMKL, IntelFFTW):
+class Impmkl(Impich, IntelMKL, IntelFFTW):
     """
-    Compiler toolchain with Intel compilers (icc/ifort), MPICH2,
+    Compiler toolchain with Intel compilers (icc/ifort), MPICH,
     Intel Math Kernel Library (MKL) and Intel FFTW wrappers.
     """
     NAME = 'impmkl'
