@@ -34,6 +34,7 @@ Support for PBS is provided via the PbsJob class. If you want you could create o
 """
 import math
 import os
+import subprocess
 
 import easybuild.tools.config as config
 from easybuild.framework.easyblock import get_easyblock_instance
@@ -118,12 +119,41 @@ def build_easyconfigs_in_parallel(build_command, easyconfigs, output_dir=None):
     return jobs
 
 
+def submit_jobs(ordered_ecs, cmd_line_opts, testing=False):
+    """
+    Submit jobs.
+    @param ordered_ecs: list of easyconfigs, in the order they should be processed
+    @param cmd_line_opts: list of command line options (in 'longopt=value' form)
+    """
+    curdir = os.getcwd()
+
+    # the options to ignore (help options can't reach here)
+    ignore_opts = ['robot', 'job']
+
+    # generate_cmd_line returns the options in form --longopt=value
+    opts = [x for x in cmd_line_opts if not x.split('=')[0] in ['--%s' % y for y in ignore_opts]]
+
+    quoted_opts = subprocess.list2cmdline(opts)
+
+    command = "unset TMPDIR && cd %s && eb %%(spec)s %s --testoutput=%%(output_dir)s" % (curdir, quoted_opts)
+    _log.info("Command template for jobs: %s" % command)
+    job_info_lines = []
+    if testing:
+        _log.debug("Skipping actual submission of jobs since testing mode is enabled")
+    else:
+        jobs = build_easyconfigs_in_parallel(command, ordered_ecs)
+        job_info_lines = ["List of submitted jobs:"]
+        job_info_lines.extend(["%s (%s): %s" % (job.name, job.module, job.jobid) for job in jobs])
+        job_info_lines.append("(%d jobs submitted)" % len(jobs))
+        return '\n'.join(job_info_lines)
+
+
 def create_job(build_command, easyconfig, output_dir=None, conn=None, ppn=None):
     """
     Creates a job, to build a *single* easyconfig
     @param build_command: format string for command, full path to an easyconfig file will be substituted in it
     @param easyconfig: easyconfig as processed by process_easyconfig
-    @param output_dir: optional output path; $EASYBUILDTESTOUTPUT will be set inside the job with this variable
+    @param output_dir: optional output path; --regtest-output-dir will be used inside the job with this variable
     @param conn: open connection to PBS server
     @param ppn: ppn setting to use (# 'processors' (cores) per node to use)
     returns the job
@@ -131,9 +161,6 @@ def create_job(build_command, easyconfig, output_dir=None, conn=None, ppn=None):
     if output_dir is None:
         output_dir = 'easybuild-build'
 
-    # create command based on build_command template
-    command = build_command % {'spec': easyconfig['spec']}
-
     # capture PYTHONPATH, MODULEPATH and all variables starting with EASYBUILD
     easybuild_vars = {}
     for name in os.environ:
@@ -152,8 +179,11 @@ def create_job(build_command, easyconfig, output_dir=None, conn=None, ppn=None):
     ec_tuple = (easyconfig['ec']['name'], det_full_ec_version(easyconfig['ec']))
     name = '-'.join(ec_tuple)
 
-    var = config.OLDSTYLE_ENVIRONMENT_VARIABLES['test_output_path']
-    easybuild_vars[var] = os.path.join(os.path.abspath(output_dir), name)
+    # create command based on build_command template
+    command = build_command % {
+        'spec': easyconfig['spec'],
+        'output_dir': os.path.join(os.path.abspath(output_dir), name),
+    }
 
     # just use latest build stats
     repo = init_repository(get_repository(), get_repositorypath())
