@@ -79,19 +79,23 @@ class EasyBlockTest(EnhancedTestCase):
 
         def check_extra_options_format(extra_options):
             """Make sure extra_options value is of correct format."""
-            # EasyBuild v1.x
-            self.assertTrue(isinstance(extra_options, list))
+            # EasyBuild v1.x: list of (<string>, <list>) tuples
+            self.assertTrue(isinstance(list(extra_options), list))  # conversion to a list works
             for extra_option in extra_options:
                 self.assertTrue(isinstance(extra_option, tuple))
                 self.assertEqual(len(extra_option), 2)
                 self.assertTrue(isinstance(extra_option[0], basestring))
                 self.assertTrue(isinstance(extra_option[1], list))
                 self.assertEqual(len(extra_option[1]), 3)
-            # EasyBuild v2.0 (breaks backward compatibility compared to v1.x)
-            #self.assertTrue(isinstance(extra_options, dict))
-            #for key in extra_options:
-            #    self.assertTrue(isinstance(extra_options[key], list))
-            #    self.assertTrue(len(extra_options[key]), 3)
+            # EasyBuild v2.0: dict with <string> keys and <list> values
+            # (breaks backward compatibility compared to v1.x)
+            self.assertTrue(isinstance(dict(extra_options), dict))  # conversion to a dict works
+            extra_options.items()
+            extra_options.keys()
+            extra_options.values()
+            for key in extra_options.keys():
+                self.assertTrue(isinstance(extra_options[key], list))
+                self.assertTrue(len(extra_options[key]), 3)
 
         name = "pi"
         version = "3.14"
@@ -115,6 +119,12 @@ class EasyBlockTest(EnhancedTestCase):
         sys.stdout.close()
         sys.stdout = stdoutorig
 
+        # check whether 'This is easyblock' log message is there
+        tup = ('EasyBlock', 'easybuild.framework.easyblock', '.*easybuild/framework/easyblock.pyc*')
+        eb_log_msg_re = re.compile(r"INFO This is easyblock %s from module %s (%s)" % tup, re.M)
+        logtxt = read_file(eb.logfile)
+        self.assertTrue(eb_log_msg_re.search(logtxt), "Pattern '%s' found in: %s" % (eb_log_msg_re.pattern, logtxt))
+
         # test extensioneasyblock, as extension
         exeb1 = ExtensionEasyBlock(eb, {'name': 'foo', 'version': '0.0'})
         self.assertEqual(exeb1.cfg['name'], 'foo')
@@ -268,6 +278,7 @@ class EasyBlockTest(EnhancedTestCase):
         version = "3.14"
         deps = [('GCC', '4.6.4')]
         hiddendeps = [('toy', '0.0-deps')]
+        alldeps = deps + hiddendeps  # hidden deps must be included in list of deps
         modextravars = {'PI': '3.1415', 'FOO': 'bar'}
         modextrapaths = {'PATH': 'pibin', 'CPATH': 'pi/include'}
         self.contents = '\n'.join([
@@ -276,7 +287,7 @@ class EasyBlockTest(EnhancedTestCase):
             'homepage = "http://example.com"',
             'description = "test easyconfig"',
             "toolchain = {'name': 'dummy', 'version': 'dummy'}",
-            "dependencies = %s" % str(deps),
+            "dependencies = %s" % str(alldeps),
             "hiddendependencies = %s" % str(hiddendeps),
             "builddependencies = [('OpenMPI', '1.6.4-GCC-4.6.4')]",
             "modextravars = %s" % str(modextravars),
@@ -383,6 +394,12 @@ class EasyBlockTest(EnhancedTestCase):
         eb = get_easyblock_instance(ec)
         self.assertTrue(isinstance(eb, EB_toy))
 
+        # check whether 'This is easyblock' log message is there
+        tup = ('EB_toy', 'easybuild.easyblocks.toy', '.*test/framework/sandbox/easybuild/easyblocks/toy.pyc*')
+        eb_log_msg_re = re.compile(r"INFO This is easyblock %s from module %s (%s)" % tup, re.M)
+        logtxt = read_file(eb.logfile)
+        self.assertTrue(eb_log_msg_re.search(logtxt), "Pattern '%s' found in: %s" % (eb_log_msg_re.pattern, logtxt))
+
     def test_obtain_file(self):
         """Test obtain_file method."""
         toy_tarball = 'toy-0.0.tar.gz'
@@ -516,6 +533,25 @@ class EasyBlockTest(EnhancedTestCase):
         os.environ['EASYBUILD_MODULE_NAMING_SCHEME'] = self.orig_module_naming_scheme
         init_config(build_options=build_options)
 
+    def test_patch_step(self):
+        """Test patch step."""
+        ec = process_easyconfig(os.path.join(os.path.abspath(os.path.dirname(__file__)), 'easyconfigs', 'toy-0.0.eb'))[0]
+        orig_sources = ec['ec']['sources'][:]
+
+        # test applying patches without sources
+        ec['ec']['sources'] = []
+        eb = EasyBlock(ec['ec'])
+        eb.fetch_step()
+        eb.extract_step()
+        self.assertErrorRegex(EasyBuildError, '.*', eb.patch_step)
+
+        # test actual patching of unpacked sources
+        ec['ec']['sources'] = orig_sources
+        eb = EasyBlock(ec['ec'])
+        eb.fetch_step()
+        eb.extract_step()
+        eb.patch_step()
+
     def tearDown(self):
         """ make sure to remove the temporary file """
         super(EasyBlockTest, self).tearDown()
