@@ -76,7 +76,7 @@ class ModulesToolTest(EnhancedTestCase):
         os.environ['module'] = "() {  eval `/bin/echo $*`\n}"
 
         # ue empty mod_path list, otherwise the install_path is called
-        mmt = MockModulesTool(mod_paths=[])
+        mmt = MockModulesTool(mod_paths=[], testing=True)
 
         # the version of the MMT is the commandline option
         self.assertEqual(mmt.version, StrictVersion(MockModulesTool.VERSION_OPTION))
@@ -91,7 +91,7 @@ class ModulesToolTest(EnhancedTestCase):
         os.environ['module'] = "() { %s $*\n}" % BrokenMockModulesTool.COMMAND
 
         try:
-            bmmt = BrokenMockModulesTool(mod_paths=[])
+            bmmt = BrokenMockModulesTool(mod_paths=[], testing=True)
             # should never get here
             self.assertTrue(False, 'BrokenMockModulesTool should fail')
         except EasyBuildError, err:
@@ -100,7 +100,7 @@ class ModulesToolTest(EnhancedTestCase):
         os.environ[BrokenMockModulesTool.COMMAND_ENVIRONMENT] = MockModulesTool.COMMAND
         os.environ['module'] = "() { /bin/echo $*\n}"
         BrokenMockModulesTool._instances.pop(BrokenMockModulesTool, None)
-        bmmt = BrokenMockModulesTool(mod_paths=[])
+        bmmt = BrokenMockModulesTool(mod_paths=[], testing=True)
         cmd_abspath = which(MockModulesTool.COMMAND)
 
         self.assertEqual(bmmt.version, StrictVersion(MockModulesTool.VERSION_OPTION))
@@ -112,8 +112,9 @@ class ModulesToolTest(EnhancedTestCase):
     def test_module_mismatch(self):
         """Test whether mismatch detection between modules tool and 'module' function works."""
         # redefine 'module' function (deliberate mismatch with used module command in MockModulesTool)
-        os.environ['module'] = "() {  eval `/Users/kehoste/Modules/$MODULE_VERSION/bin/modulecmd bash $*`\n}"
-        self.assertErrorRegex(EasyBuildError, ".*pattern .* not found in defined 'module' function", MockModulesTool)
+        os.environ['module'] = "() {  eval `/tmp/Modules/$MODULE_VERSION/bin/modulecmd bash $*`\n}"
+        error_regex = ".*pattern .* not found in defined 'module' function"
+        self.assertErrorRegex(EasyBuildError, error_regex, MockModulesTool, testing=True)
 
         # check whether escaping error by allowing mismatch via build options works
         build_options = {
@@ -123,7 +124,7 @@ class ModulesToolTest(EnhancedTestCase):
 
         fancylogger.logToFile(self.logfile)
 
-        mt = MockModulesTool()
+        mt = MockModulesTool(testing=True)
         f = open(self.logfile, 'r')
         logtxt = f.read()
         f.close()
@@ -133,13 +134,13 @@ class ModulesToolTest(EnhancedTestCase):
         # redefine 'module' function with correct module command
         os.environ['module'] = "() {  eval `/bin/echo $*`\n}"
         MockModulesTool._instances.pop(MockModulesTool)
-        mt = MockModulesTool()
+        mt = MockModulesTool(testing=True)
         self.assertTrue(isinstance(mt.loaded_modules(), list))  # dummy usage
 
         # a warning should be logged if the 'module' function is undefined
         del os.environ['module']
         MockModulesTool._instances.pop(MockModulesTool)
-        mt = MockModulesTool()
+        mt = MockModulesTool(testing=True)
         f = open(self.logfile, 'r')
         logtxt = f.read()
         f.close()
@@ -173,8 +174,7 @@ class ModulesToolTest(EnhancedTestCase):
 
             # initialize Lmod modules tool, pass full path to 'lmod' via $LMOD_CMD
             os.environ['LMOD_CMD'] = lmod_abspath
-            lmod = Lmod()
-            lmod.testing = True
+            lmod = Lmod(testing=True)
 
             # obtain list of availabe modules, should be non-empty
             self.assertTrue(lmod.available(), "List of available modules obtained using Lmod is non-empty")
