@@ -324,7 +324,7 @@ def thread_name():
     return threading.currentThread().getName()
 
 
-def getLogger(name=None, fname=True, clsname=False, fancyrecord=None):
+def getLogger(name=None, fname=False, clsname=False, fancyrecord=None):
     """
     returns a fancylogger
     if fname is True, the loggers name will be 'name[.classname].functionname'
@@ -352,8 +352,10 @@ def getLogger(name=None, fname=True, clsname=False, fancyrecord=None):
     if os.environ.get('FANCYLOGGER_GETLOGGER_DEBUG', '0').lower() in ('1', 'yes', 'true', 'y'):
         print 'FANCYLOGGER_GETLOGGER_DEBUG',
         print 'name', name, 'fname', fname, 'fullname', fullname,
-        print 'parent_info verbose'
-        print "\n".join(l.get_parent_info("FANCYLOGGER_GETLOGGER_DEBUG"))
+        print "getRootLoggerName: ", getRootLoggerName()
+        if hasattr(l, 'get_parent_info'):
+            print 'parent_info verbose'
+            print "\n".join(l.get_parent_info("FANCYLOGGER_GETLOGGER_DEBUG"))
         sys.stdout.flush()
     return l
 
@@ -683,8 +685,8 @@ def enableDefaultHandlers():
 def getDetailsLogLevels(fancy=True):
     """
     Return list of (name,loglevelname) pairs of existing loggers
-    
-    @param fancy: if True, returns only Fancylogger; if False, returns non-FancyLoggers, 
+
+    @param fancy: if True, returns only Fancylogger; if False, returns non-FancyLoggers,
                   anything else, return all loggers
     """
     func_map = {
